==> apache-camel-3.7.7-src.zip: apache-camel-3.7.7/components/camel-servicenow/camel-servicenow-component/src/main/java/org/apache/camel/component/servicenow/model/Reference.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.servicenow.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Reference {
    private final String link;
    private final String value;
    private final String displayValue;

    @JsonCreator
    public Reference(String value) {
        this.link = null;
        this.value = value;
        this.displayValue = null;
    }

    @JsonCreator
    public Reference(
                     @JsonProperty(value = "link", required = false)
                     String link,
                     @JsonProperty(value = "value", required = true)
                     String value,
                     @JsonProperty(value = "display_value", required = false)
                     String displayValue) {

        this.link = link;
        this.value = value;
        this.displayValue = displayValue;
    }

    public String getLink() {
        return link;
    }

    public String getValue() {
        return value;
    }

    public String getDisplayValue() {
        return displayValue;
    }
}

==> apache-camel-4.8.7-src.zip: apache-camel-4.8.7/components/camel-servicenow/camel-servicenow-component/src/main/java/org/apache/camel/component/servicenow/model/Reference.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.servicenow.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Reference {
    private final String link;
    private final String value;
    private final String displayValue;

    @JsonCreator
    public Reference(String value) {
        this.link = null;
        this.value = value;
        this.displayValue = null;
    }

    @JsonCreator
    public Reference(
                     @JsonProperty(value = "link", required = false) String link,
                     @JsonProperty(value = "value", required = true) String value,
                     @JsonProperty(value = "display_value", required = false) String displayValue) {

        this.link = link;
        this.value = value;
        this.displayValue = displayValue;
    }

    public String getLink() {
        return link;
    }

    public String getValue() {
        return value;
    }

    public String getDisplayValue() {
        return displayValue;
    }
}
